@@ -3,7 +3,6 @@
 /**
  * display selection for relational field values
  *
- * @version $Id$
  * @package phpMyAdmin
  */
 
@@ -22,8 +21,6 @@ require_once './libraries/header_http.inc.php';
 /**
  * Displays the frame
  */
-$per_page = 200;
-require_once './libraries/relation.lib.php'; // foreign keys
 require_once './libraries/transformations.lib.php'; // Transformations
 $cfgRelation = PMA_getRelationsParam();
 $foreigners  = ($cfgRelation['relwork'] ? PMA_getForeigners($db, $table) : FALSE);
@@ -34,20 +31,17 @@ if (!isset($pos)) {
     $pos = 0;
 }
 
-$foreign_limit = 'LIMIT ' . $pos . ', ' . $per_page . ' ';
-if (isset($foreign_navig) && $foreign_navig == $strShowAll) {
+$foreign_limit = 'LIMIT ' . $pos . ', ' . $GLOBALS['cfg']['MaxRows'] . ' ';
+if (isset($foreign_navig) && $foreign_navig == __('Show all')) {
     unset($foreign_limit);
 }
 
 $foreignData = PMA_getForeignData($foreigners, $field, $override_total, isset($foreign_filter) ? $foreign_filter : '', $foreign_limit);
 
-if (isset($pk)) {
-    $pk_uri = '&amp;pk=' . urlencode($pk);
-    ?>
-<input type="hidden" name="pk" value="<?php echo htmlspecialchars($pk); ?>" />
-    <?php
+if (isset($rownumber)) {
+    $rownumber_param = '&amp;rownumber=' . urlencode($rownumber);
 } else {
-    $pk_uri = '';
+    $rownumber_param = '';
 }
 
 $gotopage = '';
@@ -55,22 +49,16 @@ $showall = '';
 
 if (is_array($foreignData['disp_row'])) {
 
-    if ($cfg['ShowAll'] && ($foreignData['the_total'] > $per_page)) {
-        $showall = '<input type="submit" name="foreign_navig" value="' . $strShowAll . '" />';
+    if ($cfg['ShowAll'] && ($foreignData['the_total'] > $GLOBALS['cfg']['MaxRows'])) {
+        $showall = '<input type="submit" name="foreign_navig" value="' . __('Show all') . '" />';
     }
 
-    $session_max_rows = $per_page;
+    $session_max_rows = $GLOBALS['cfg']['MaxRows'];
     $pageNow = @floor($pos / $session_max_rows) + 1;
     $nbTotalPage = @ceil($foreignData['the_total'] / $session_max_rows);
 
-    if ($foreignData['the_total'] > $per_page) {
+    if ($foreignData['the_total'] > $GLOBALS['cfg']['MaxRows']) {
         $gotopage = PMA_pageselector(
-                      'browse_foreigners.php?field='    . urlencode($field) .
-                                       '&amp;'          . PMA_generate_common_url($db, $table)
-                                                        . $pk_uri .
-                                       '&amp;fieldkey=' . (isset($fieldkey) ? urlencode($fieldkey) : '') .
-                                       '&amp;foreign_filter=' . (isset($foreign_filter) ? urlencode($foreign_filter) : '') .
-                                       '&amp;',
                       $session_max_rows,
                       $pageNow,
                       $nbTotalPage,
@@ -79,7 +67,7 @@ if (is_array($foreignData['disp_row'])) {
                       5,
                       20,
                       10,
-                      $GLOBALS['strPageNumber']
+                      __('Page number:')
                     );
     }
 }
@@ -87,25 +75,38 @@ if (is_array($foreignData['disp_row'])) {
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml"
-    xml:lang="<?php echo $available_languages[$lang][2]; ?>"
-    lang="<?php echo $available_languages[$lang][2]; ?>"
+    xml:lang="<?php echo $available_languages[$lang][1]; ?>"
+    lang="<?php echo $available_languages[$lang][1]; ?>"
     dir="<?php echo $text_dir; ?>">
 
 <head>
     <title>phpMyAdmin</title>
     <meta http-equiv="Content-Type" content="text/html; charset=<?php echo $charset; ?>" />
     <link rel="stylesheet" type="text/css"
-        href="phpmyadmin.css.php?<?php echo PMA_generate_common_url('', ''); ?>&amp;js_frame=right&amp;nocache=<?php echo $_SESSION['PMA_Config']->getThemeUniqueValue(); ?>" />
-    <script src="./js/functions.js" type="text/javascript"></script>
+        href="phpmyadmin.css.php?<?php echo PMA_generate_common_url('', ''); ?>&amp;js_frame=right&amp;nocache=<?php echo $GLOBALS['PMA_Config']->getThemeUniqueValue(); ?>" />
+<?php
+// includes everything asked for by libraries/common.inc.php
+require_once './libraries/header_scripts.inc.php';
+?>
     <script type="text/javascript">
     //<![CDATA[
     self.focus();
-    function formupdate(field, key) {
-        if (opener && opener.document && opener.document.insertForm) {
-            var field = 'field_' + field;
+    function formupdate(fieldmd5, key) {
+        var $inline = window.opener.jQuery('.browse_foreign_clicked');
+        if ($inline.length != 0) {
+            $inline.removeClass('browse_foreign_clicked')
+                // puts new value in the previous element which is
+                // a span with class curr_value
+                .prev().text(key);
+            self.close();
+            return false;
+        }
 
-            <?php if (isset($pk)) { ?>
-            var element_name = field + '[multi_edit][<?php echo htmlspecialchars($pk); ?>][]';
+        if (opener && opener.document && opener.document.insertForm) {
+            var field = 'fields';
+
+            <?php if (isset($rownumber)) { ?>
+            var element_name = field + '[multi_edit][<?php echo htmlspecialchars($rownumber); ?>][' + fieldmd5 + ']';
             <?php } else { ?>
             var element_name = field + '[]';
             <?php } ?>
@@ -129,7 +130,7 @@ if (is_array($foreignData['disp_row'])) {
             }
         }
 
-        alert('<?php echo PMA_jsFormat($strWindowNotFound); ?>');
+        alert('<?php echo PMA_jsFormat(__('The target browser window could not be updated. Maybe you have closed the parent window, or your browser\'s security settings are configured to block cross-window updates.')); ?>');
     }
     //]]>
     </script>
@@ -143,14 +144,14 @@ if (is_array($foreignData['disp_row'])) {
 <input type="hidden" name="field" value="<?php echo htmlspecialchars($field); ?>" />
 <input type="hidden" name="fieldkey"
     value="<?php echo isset($fieldkey) ? htmlspecialchars($fieldkey) : ''; ?>" />
-<?php if (isset($pk)) { ?>
-<input type="hidden" name="pk" value="<?php echo htmlspecialchars($pk); ?>" />
+<?php if (isset($rownumber)) { ?>
+<input type="hidden" name="rownumber" value="<?php echo htmlspecialchars($rownumber); ?>" />
 <?php } ?>
 <span class="formelement">
-    <label for="input_foreign_filter"><?php echo $strSearch . ':'; ?></label>
+    <label for="input_foreign_filter"><?php echo __('Search') . ':'; ?></label>
     <input type="text" name="foreign_filter" id="input_foreign_filter"
         value="<?php echo isset($foreign_filter) ? htmlspecialchars($foreign_filter) : ''; ?>" />
-    <input type="submit" name="submit_foreign_filter" value="<?php echo $strGo;?>" />
+    <input type="submit" name="submit_foreign_filter" value="<?php echo __('Go');?>" />
 </span>
 <span class="formelement">
     <?php echo $gotopage; ?>
@@ -165,11 +166,11 @@ if (is_array($foreignData['disp_row'])) {
 <?php
 if (is_array($foreignData['disp_row'])) {
     $header = '<tr>
-        <th>' . $strKeyname . '</th>
-        <th>' . $strDescription . '</th>
+        <th>' . __('Keyname') . '</th>
+        <th>' . __('Description') . '</th>
         <td width="20%"></td>
-        <th>' . $strDescription . '</th>
-        <th>' . $strKeyname . '</th>
+        <th>' . __('Description') . '</th>
+        <th>' . __('Keyname') . '</th>
     </tr>';
 
     echo '<thead>' . $header . '</thead>' . "\n"
@@ -240,11 +241,11 @@ if (is_array($foreignData['disp_row'])) {
         }
 
         ?>
-    <tr class="<?php echo $odd_row ? 'odd' : 'even'; $odd_row = ! $odd_row; ?>">
+    <tr class="noclick <?php echo $odd_row ? 'odd' : 'even'; $odd_row = ! $odd_row; ?>">
         <td nowrap="nowrap">
         <?php
         echo ($key_ordered_current_equals_data ? '<strong>' : '')
-            .'<a href="#" title="' . $strUseThisValue
+            .'<a href="#" title="' . __('Use this value')
             . ($key_ordered_current_val_title != '' ? ': ' . $key_ordered_current_val_title : '') . '"'
             .' onclick="formupdate(\'' . md5($field) . '\', \''
             . PMA_jsFormat($key_ordered_current_key, false) . '\'); return false;">'
@@ -253,19 +254,19 @@ if (is_array($foreignData['disp_row'])) {
         <td>
         <?php
         echo ($key_ordered_current_equals_data ? '<strong>' : '')
-            . '<a href="#" title="' . $strUseThisValue . ($key_ordered_current_val_title != '' ? ': '
+            . '<a href="#" title="' . __('Use this value') . ($key_ordered_current_val_title != '' ? ': '
             . $key_ordered_current_val_title : '') . '" onclick="formupdate(\''
             . md5($field) . '\', \'' . PMA_jsFormat($key_ordered_current_key, false) . '\'); return false;">'
             . $key_ordered_current_val . '</a>' . ($key_ordered_current_equals_data ? '</strong>' : '');
         ?></td>
         <td width="20%">
             <img src="<?php echo $GLOBALS['pmaThemeImage'] . 'spacer.png'; ?>"
-                alt="" width="1" height="1"></td>
+                alt="" width="1" height="1" /></td>
 
         <td>
         <?php
         echo ($val_ordered_current_equals_data ? '<strong>' : '')
-            . '<a href="#" title="' . $strUseThisValue .  ($val_ordered_current_val_title != '' ? ': '
+            . '<a href="#" title="' . __('Use this value') .  ($val_ordered_current_val_title != '' ? ': '
             . $val_ordered_current_val_title : '') . '" onclick="formupdate(\'' . md5($field)
             . '\', \'' . PMA_jsFormat($val_ordered_current_key, false) . '\'); return false;">'
             . $val_ordered_current_val . '</a>' . ($val_ordered_current_equals_data ? '</strong>' : '');
@@ -273,7 +274,7 @@ if (is_array($foreignData['disp_row'])) {
         <td nowrap="nowrap">
         <?php
         echo ($val_ordered_current_equals_data ? '<strong>' : '') . '<a href="#" title="'
-        . $strUseThisValue .  ($val_ordered_current_val_title != '' ? ': ' . $val_ordered_current_val_title : '')
+        . __('Use this value') .  ($val_ordered_current_val_title != '' ? ': ' . $val_ordered_current_val_title : '')
         . '" onclick="formupdate(\'' . md5($field) . '\', \''
         . PMA_jsFormat($val_ordered_current_key, false) . '\'); return false;">' . htmlspecialchars($val_ordered_current_key)
         . '</a>' . ($val_ordered_current_equals_data ? '</strong>' : '');
