@@ -3,7 +3,6 @@
 /**
  * Holds class PMA_Error
  *
- * @version $Id$
  * @package phpMyAdmin
  */
 
@@ -48,15 +47,15 @@ class PMA_Error extends PMA_Message
      */
     static public $errorlevel = array (
         E_ERROR              => 'error',
-        E_WARNING            => 'warning',
+        E_WARNING            => 'error',
         E_PARSE              => 'error',
         E_NOTICE             => 'notice',
         E_CORE_ERROR         => 'error',
-        E_CORE_WARNING       => 'warning',
+        E_CORE_WARNING       => 'error',
         E_COMPILE_ERROR      => 'error',
-        E_COMPILE_WARNING    => 'warning',
+        E_COMPILE_WARNING    => 'error',
         E_USER_ERROR         => 'error',
-        E_USER_WARNING       => 'warning',
+        E_USER_WARNING       => 'error',
         E_USER_NOTICE        => 'notice',
         E_STRICT             => 'notice',
         E_DEPRECATED         => 'notice',
