@@ -17,9 +17,8 @@
  * (It's slower to have PHP do the count).
  *
  * It's easier to use only uppercase for proper sorting. In case of
- * doubt, use the DEBUG code after this function's definition.
+ * doubt, use the test case to verify.
  *
- * @version $Id$
  * @package phpMyAdmin
  */
 if (! defined('PHPMYADMIN')) {
@@ -340,17 +339,6 @@ $PMA_SQPdata_function_name = array (
  */
 $PMA_SQPdata_function_name_cnt = 298;
 
-/*
- * DEBUG
-$test_PMA_SQPdata_function_name = $PMA_SQPdata_function_name;
-sort($PMA_SQPdata_function_name);
-if ($PMA_SQPdata_function_name != $test_PMA_SQPdata_function_name) {
-    echo 'sort properly like this<pre>';
-    print_r($PMA_SQPdata_function_name);
-    echo '</pre>';
-}
- */
-
 /**
  * @global array MySQL attributes
  */
@@ -539,7 +527,6 @@ $PMA_SQPdata_reserved_word = array (
     'LOGS',
     'LOW_PRIORITY',
     'MARIA',                // 5.1 ?
-    'MASTER',
     'MASTER_CONNECT_RETRY',
     'MASTER_HOST',
     'MASTER_LOG_FILE',
@@ -581,6 +568,7 @@ $PMA_SQPdata_reserved_word = array (
     'OUTFILE',
     'PACK_KEYS',
     'PAGE',                 // 5.1-maria ?
+    'PAGE_CHECKSUM',        // 5.1
     'PARTIAL',
     'PARTITION',            // 5.1
     'PARTITIONS',           // 5.1
@@ -697,23 +685,6 @@ $PMA_SQPdata_reserved_word = array (
  * @global integer MySQL reserved words count
  */
 $PMA_SQPdata_reserved_word_cnt = 287;
-/**
- * The previous array must be sorted so that the binary search work.
- * Sometimes a word is not added in the correct order, so
- * this debugging code shows the problem. The same should be
- * done for all arrays.
- */
-/*
-$original = $PMA_SQPdata_reserved_word;
-sort($PMA_SQPdata_reserved_word);
-$difference = array_diff_assoc($original, $PMA_SQPdata_reserved_word);
-echo '<pre>';
-print_r($difference);
-echo '</pre>';
-echo '<pre>';
-print_r($PMA_SQPdata_reserved_word);
-echo '</pre>';
-*/
 
 /**
  * words forbidden to be used as column or table name wihtout quotes
@@ -1283,10 +1254,4 @@ $PMA_SQPdata_column_type = array (
  */
 $PMA_SQPdata_column_type_cnt = 54;
 
-/*
- * check counts
-foreach ($GLOBALS as $n => $a) {
-    echo is_array($a) ? $n . ': ' . count($a) . '<br />' : '';
-}
- */
 ?>
