@@ -1,10 +1,15 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
- *
- * @version $Id: text_plain__dateformat.inc.php 10239 2007-04-01 09:51:41Z cybot_tm $
+ * @package phpMyAdmin-Transformation
  */
 
+function PMA_transformation_text_plain__longToIpv4_info() {
+    return array(
+        'info' => __('Converts an (IPv4) Internet network address into a string in Internet standard dotted format.'),
+        );
+}
+
 /**
  * returns IPv4 address
  *
